Module fluent_static::fluent_bundle
source · Structs
- Fluent messages can use arguments in order to programmatically add values to a translated string. For instance, in a localized application you may wish to display a user’s email count. This could be done with the following message.
FluentMessageis a basic translation unit of the Fluent system.- A resource containing a list of localization messages.
Enums
- Core error type for Fluent runtime system.
- The
FluentValueenum represents values which can be formatted to a String.
Type Aliases
- Specialized
FluentBundleover concurrentIntlLangMemoizer.